% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_all_contacts.R
\name{get_all_contacts}
\alias{get_all_contacts}
\title{Get Export of All Email Contact Events}
\usage{
get_all_contacts(
  pod_number,
  session_access_token,
  start_date,
  end_date,
  date_type = "EVENT",
  event_types = "<ALL_EVENT_TYPES/>",
  export_format = 0,
  exclude_deleted = FALSE,
  optional_columns = TRUE,
  file_name_prefix = "",
  confirm_email = ""
)
}
\arguments{
\item{pod_number}{Pod number is the number in the URL, e.g.
engage1.silverpop.com.}

\item{session_access_token}{Access token obtained during this session.}

\item{start_date}{Filter for emails sent on or after this date.}

\item{end_date}{Filter for emails sent on or before this date.}

\item{date_type}{Select whether the date filters should be on the event
date or the email sent date ("EVENT" or "SENT").}

\item{event_types}{There are 18 different events. By default all event
types are returned. This parameter takes XML arguments where you can
override the default and specify all of the events you want. See the
Acoustic documentation for the full list.}

\item{export_format}{Acoustic provides three delimeter file types:
0 (CSV), 1 (PIPE), or 2 (TAB). CSV is the default used here.}

\item{exclude_deleted}{Do you want to exclude contacts that have been
deleted, can be TRUE/FALSE. Per Acoustic, "Inclusion of this
element can greatly decrease the time to generate the metrics file and
is useful whenever metrics for deleted contacts are not required."}

\item{optional_columns}{Do you want to include four optional columns
in the results, can be TRUE/FALSE. These columns are the mailing name,
mailing subject, the from email address and the from email name.}

\item{file_name_prefix}{Optional argument that should be used if you
want to add a particular prefix to the file that you will download
from your portal.}

\item{confirm_email}{Optional argument to specify an email address
where IBM will let you know when the job has completed.}
}
\value{
A vector with the Job Id.
}
\description{
This function submits a job to Acoustic that exports all email contact
events. Various criteria are available to filter the export. Some,
but not all, of these have been built into the parameters of this
function. Reading the IBM Acoustic documentation is useful:
https://developer.ibm.com/customer-engagement/tutorials/
export-raw-contact-events/
}
\details{
The date type is sent to EVENT by default. If you filter by the sent
date you may not get all applicable events, as some events (a future
click) will not yet have happened. If you do filter by SENT date and
are incrementally updating your data you should plan to go back and
retroactively update past dates.

Job results are available as exports in the Silverpop portal by
going to Resources -> Data Jobs.

It is not recommended that these authentication parameters be
stored directly in your code. There are various methods and
packages available that are more secure; this package does not
require you to use any one in particular.
}
\examples{
\dontrun{
access_token <- acoustic_auth(org_client_id = "abc",
org_client_secret = "xyz",
my_refresh_token = "123")

job_id <- get_all_contacts(pod_number, access_token,
"2020-01-01", "2020-01-05", event_types = "<CLICKS/>",
1, exclude_deleted = TRUE, optional_columns = TRUE)
}
}
